/*
  File name        : calloc.h
  Date of creation : 11/5/2009
  Version          : 1.0
  Copyright        : Soft'n'design
  Author           : Laurent Mazet <mazet@softndesign.org>

  Description      : This file contains macros for debugging

  History          :
  - initial version
*/

#ifndef __CALLOC_H__
#define __CALLOC_H__

#include <unistd.h>

__BEGIN_DECLS

/**
   Debug memory allocation functions
*/
extern int check_memory_allocation_;
int check_memory_allocation (void);

/**
   Allocate a memory block.

   @param size memory block size
   @return memory pointer
*/
#define malloc(size) mymalloc (size, "#"__FILE__, __LINE__)
void *mymalloc (size_t size, const char *file, const int line);

/**
   Allocate a memory block filled of zeros.

   @param nmemb number of member
   @param size member size
   @return memory pointer
*/
#define calloc(nmemb, size) mycalloc ((nmemb) * (size), "#"__FILE__, __LINE__)
void *mycalloc (size_t size, const char *file, const int line);

/**
   Free a memory block.

   @param pt memory pointer
*/
#define free(pt) myfree (pt, "#"__FILE__, __LINE__)
void myfree (void *pt, const char *file, const int line);

/**
   Allocate a memory bloc filled of zerosa and copy data fron old
   assigned pointer.

   @param pt old memory pointer
   @param size memory block size
   @return new memory pointer
*/
#define realloc(pt, size) myrealloc (pt, size, "#"__FILE__, __LINE__)
void *myrealloc (void *pt, size_t size, const char *file, const int line);

/**
   Display memory allocation table
*/
void display_allocation_table (void);

__END_DECLS

#endif /* __CALLOC_H__ */

/* vi:set tabstop=4 expandtab shiftwidth=4: this line set vi mode */
